/*
 * ImageConverter.hpp
 *
 *  Created on: 22.11.2017
 *      Author: ubuntu
 */

#ifndef SRC_MODULES_IMAGECONVERTER_IMAGECONVERTER_HPP_
#define SRC_MODULES_IMAGECONVERTER_IMAGECONVERTER_HPP_

//#include "../../OpenCV_includes.hpp"
#include "../main_loop/mainloop.hpp"


#include <ros/ros.h>
#include <image_transport/image_transport.h>
#include <cv_bridge/cv_bridge.h>
#include <sensor_msgs/image_encodings.h>


#include "messages/Trajectory.h"
#include "RosPublisher.h"
#include "RosSubscriber.h"

static const std::string OPENCV_WINDOW = "Image window";

class ImageConverter : public velox::utils::base::RosPublisher {

	private:

		ros::NodeHandle nh_;
		image_transport::ImageTransport it_;
		image_transport::Subscriber image_sub_;
		ros::Publisher pub;
		cv::Mat img;
		main_loop main;

		messages::Trajectory trajectoryRosMessage;
		std::array<uint16_t, 10> x_out;
		std::array<int16_t, 10> y_out;
		std::array<int16_t, 10> theta_out;
		std::array<int16_t, 10> kappa_out;

//	messages::

	public:
		ImageConverter(char** argv) : it_(nh_), main(argv), RosPublisher(&nh_) {
			// Subscrive to input video feed and publish output video feed
			image_sub_ = it_.subscribe("/camera/image_raw", 1,
									   &ImageConverter::imageCb, this);

			createNewPublisher<messages::Trajectory>("Trajectory", 1000);

//			pub
		}

		void imageCb(const sensor_msgs::ImageConstPtr& msg) {
			cv_bridge::CvImagePtr cv_ptr;
			try {
				cv_ptr = cv_bridge::toCvCopy(msg,
						sensor_msgs::image_encodings::BGR8);
			} catch (cv_bridge::Exception& e) {
				ROS_ERROR("cv_bridge exception: %s", e.what());
				return;
			}

			img = cv_ptr->image;


			// Update GUI Window

//			Mat1b gray = cv_ptr->image;
			cv::Mat3b col = cv_ptr->image;
//			cout << img.cols << " x " << img.rows << endl;
//			cv::cvtColor(gray, col, CV_GRAY2BGR);
			// finde den Typ für die derzeitige Mat und konvertiere sie auf Mat3b

//			cv::imshow(OPENCV_WINDOW, col);
//			cv::waitKey(1);


			// hier die main starten
			main.loop(&(col), &x_out, &y_out, &theta_out, &kappa_out);

			for(int i = 0; i < 10; i++){
				trajectoryRosMessage.x.at(i) = y_out.at(i);
				trajectoryRosMessage.y.at(i) = x_out.at(i);
				trajectoryRosMessage.kappa.at(i) = kappa_out.at(i);
				trajectoryRosMessage.theta.at(i) = theta_out.at(i);
			}

			publish(trajectoryRosMessage, "Trajectory");

		}
};

#endif /* SRC_MODULES_IMAGECONVERTER_IMAGECONVERTER_HPP_ */
